import Link from "next/link"
import { ArrowLeft, ChevronRight } from "lucide-react"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card"
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs"

// Define the lesson data structure
type LessonSection = {
  id: string
  title: string
  content: string
  image: string
}

type Lesson = {
  id: string
  title: string
  description: string
  introduction: string
  sections: LessonSection[]
}

// Lesson data
const lessons: Record<string, Lesson> = {
  "1": {
    id: "1",
    title: "La signalisation routière",
    description: "Apprenez à reconnaître et comprendre les différents panneaux et signaux routiers.",
    introduction:
      "La signalisation routière est un élément essentiel de la sécurité sur les routes. Elle permet de réguler la circulation, d'informer les usagers et de prévenir les dangers. Cette leçon vous aidera à comprendre les différents types de panneaux et leur signification.",
    sections: [
      {
        id: "danger",
        title: "Panneaux de danger",
        content:
          "Les panneaux de danger sont de forme triangulaire avec un fond blanc et une bordure rouge. Ils avertissent les conducteurs d'un danger potentiel sur la route. Ces panneaux sont généralement placés à une distance de 150 mètres avant le danger en agglomération, et 200 mètres hors agglomération.\n\nIl est important de ralentir et d'être vigilant lorsque vous apercevez un panneau de danger. Parmi les panneaux de danger les plus courants, on trouve les virages dangereux, les passages à niveau, les traversées d'animaux, et les chaussées glissantes.",
        image: "/placeholder.svg?height=300&width=400&text=Panneaux+de+danger",
      },
      {
        id: "interdiction",
        title: "Panneaux d'interdiction",
        content:
          "Les panneaux d'interdiction sont généralement de forme circulaire avec un fond blanc et une bordure rouge. Ils indiquent une interdiction ou une restriction. Le non-respect de ces panneaux peut entraîner des sanctions.\n\nParmi les panneaux d'interdiction les plus courants, on trouve l'interdiction de dépasser, l'interdiction de stationner, la limitation de vitesse, et l'interdiction de tourner. Ces panneaux sont en vigueur à partir de l'endroit où ils sont placés jusqu'au prochain carrefour ou jusqu'à un panneau de fin d'interdiction.",
        image: "/placeholder.svg?height=300&width=400&text=Panneaux+d'interdiction",
      },
      {
        id: "obligation",
        title: "Panneaux d'obligation",
        content:
          "Les panneaux d'obligation sont de forme circulaire avec un fond bleu. Ils indiquent une obligation que le conducteur doit respecter. Le non-respect de ces panneaux peut également entraîner des sanctions.\n\nParmi les panneaux d'obligation les plus courants, on trouve l'obligation de tourner à droite ou à gauche, l'obligation de suivre une direction, et les voies réservées à certains types de véhicules. Ces panneaux sont en vigueur à partir de l'endroit où ils sont placés jusqu'au prochain carrefour ou jusqu'à un panneau de fin d'obligation.",
        image: "/placeholder.svg?height=300&width=400&text=Panneaux+d'obligation",
      },
      {
        id: "feux",
        title: "Feux tricolores",
        content:
          "Les feux tricolores sont des dispositifs lumineux qui régulent la circulation aux intersections. Ils sont composés de trois couleurs : rouge, orange (ou jaune) et vert.\n\nLe feu rouge indique l'obligation de s'arrêter. Le feu orange fixe indique l'obligation de s'arrêter, sauf si le conducteur est trop près du feu pour s'arrêter dans des conditions de sécurité suffisantes. Le feu vert indique l'autorisation de passer, sous réserve de céder le passage aux véhicules qui seraient déjà engagés dans l'intersection.\n\nLe feu orange clignotant indique que le conducteur peut passer, mais qu'il doit faire preuve d'une prudence particulière.",
        image: "/placeholder.svg?height=300&width=400&text=Feux+tricolores",
      },
    ],
  },
}

export default function LessonPage({ params }: { params: { id: string } }) {
  const lesson = lessons[params.id]

  if (!lesson) {
    return (
      <div className="min-h-screen route-pattern">
        <div className="route-header bg-white py-4 shadow-md mb-8">
          <div className="container mx-auto px-4">
            <h1 className="text-3xl font-bold text-center text-route-blue">Leçon non trouvée</h1>
            <div className="flex justify-center mt-2">
              <div className="road-line w-32"></div>
            </div>
          </div>
        </div>

        <div className="container mx-auto px-4 py-8 max-w-4xl">
          <Link href="/lessons" className="inline-flex items-center text-route-blue mb-6">
            <ArrowLeft className="mr-2 h-4 w-4" />
            Retour aux leçons
          </Link>

          <div className="text-center py-12">
            <p className="text-lg text-muted-foreground mb-8">Désolé, la leçon que vous recherchez n'existe pas.</p>
            <Button asChild className="bg-route-blue hover:bg-route-blue/90">
              <Link href="/lessons">Voir toutes les leçons</Link>
            </Button>
          </div>
        </div>
      </div>
    )
  }

  return (
    <div className="min-h-screen route-pattern">
      <div className="route-header bg-white py-4 shadow-md mb-8">
        <div className="container mx-auto px-4">
          <h1 className="text-3xl font-bold text-center text-route-blue">{lesson.title}</h1>
          <div className="flex justify-center mt-2">
            <div className="road-line w-32"></div>
          </div>
        </div>
      </div>

      <div className="container mx-auto px-4 py-8 max-w-4xl">
        <Link href="/lessons" className="inline-flex items-center text-route-blue mb-6">
          <ArrowLeft className="mr-2 h-4 w-4" />
          Retour aux leçons
        </Link>

        <div className="mb-8">
          <p className="text-lg text-muted-foreground">{lesson.description}</p>
        </div>

        <Card className="mb-8 route-card route-card-blue">
          <CardHeader>
            <CardTitle>Introduction</CardTitle>
          </CardHeader>
          <CardContent>
            <p>{lesson.introduction}</p>
          </CardContent>
        </Card>

        <Tabs defaultValue={lesson.sections[0].id} className="mb-8">
          <TabsList className="grid grid-cols-2 md:grid-cols-4 mb-8">
            {lesson.sections.map((section) => (
              <TabsTrigger key={section.id} value={section.id}>
                {section.title}
              </TabsTrigger>
            ))}
          </TabsList>

          {lesson.sections.map((section) => {
            let cardColor = "blue"
            if (section.id === "danger") cardColor = "red"
            if (section.id === "interdiction") cardColor = "red"
            if (section.id === "obligation") cardColor = "blue"
            if (section.id === "feux") cardColor = "yellow"

            return (
              <TabsContent key={section.id} value={section.id}>
                <Card className={`route-card route-card-${cardColor}`}>
                  <CardHeader>
                    <CardTitle>{section.title}</CardTitle>
                  </CardHeader>
                  <CardContent className="space-y-4">
                    <div className="rounded-md overflow-hidden mb-4 border border-gray-200">
                      <img
                        src={section.image || "/placeholder.svg"}
                        alt={section.title}
                        className="w-full object-cover"
                      />
                    </div>
                    <div className="whitespace-pre-line">{section.content}</div>
                  </CardContent>
                </Card>
              </TabsContent>
            )
          })}
        </Tabs>

        <div className="flex justify-between mt-12">
          <Button variant="outline" asChild className="border-route-blue text-route-blue hover:bg-route-blue/10">
            <Link href="/lessons">
              <ArrowLeft className="mr-2 h-4 w-4" />
              Toutes les leçons
            </Link>
          </Button>
          <Button asChild className="bg-route-blue hover:bg-route-blue/90">
            <Link href="/exercises">
              Passer aux exercices
              <ChevronRight className="ml-2 h-4 w-4" />
            </Link>
          </Button>
        </div>
      </div>
    </div>
  )
}
